<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                              xmlns="http://www.ibm.com/2010/04/CompilerTransformation">

   <xsl:output method="xml" encoding="UTF-8" indent="yes"/>

   <xsl:template match="/">
      <xsl:apply-templates select="TransformationReport"/>
   </xsl:template>

   <xsl:template match="TransformationReport">
      <!-- XML document heading -->
      <xsl:if test="count(StyleSheets/StyleSheet) > 0">
	 <xsl:processing-instruction name="xml-stylesheet">type="text/xsl" href="<xsl:value-of select="StyleSheets/StyleSheet/Name"/>"</xsl:processing-instruction>
      </xsl:if>
      <XLTransformationReport xmlns="http://www.ibm.com/2010/04/CompilerTransformation" version="1.1">
         <CompilationStep>
            <xsl:attribute name="name"><xsl:apply-templates select="CompileInfo/Compile/Kind" mode="step-name"/></xsl:attribute>
            <StepDetails>
               <xsl:apply-templates select="CompileInfo"/>
            </StepDetails>
            <ProgramHierarchy>
               <xsl:apply-templates select="SourceFiles"/>
            </ProgramHierarchy>
            <TransformationHierarchy>
               <xsl:if test="count(Transforms/Transform[TransformKind != '131594' and
                                                        TransformKind != '131596']) > 0">
               <IntraTransformationList>
                  <xsl:apply-templates select="Transforms"/>
               </IntraTransformationList>
               </xsl:if>
               <xsl:if test="count(Inlines/Inline[ResultCode != '6' and
                                                  ResultCode != '9' and
                                                  ResultCode != '13' and
                                                  ResultCode != '21' and
                                                  ResultCode != '22' and
                                                  ResultCode != '23' and
                                                  ResultCode != '31' and
                                                  ResultCode != '33' and
                                                  ResultCode != '34' and
                                                  ResultCode != '35' and
                                                  ResultCode != '38' and
                                                  ResultCode != '40' and
                                                  ResultCode != '42']) > 0 or
                             count(DataReorganizations/DataReorganization) > 0">
               <InterTransformationList>
                  <xsl:apply-templates select="Inlines"/>
                  <xsl:apply-templates select="DataReorganizations"/>
               </InterTransformationList>
               </xsl:if>
            </TransformationHierarchy>
            <ProfilingReports>
               <xsl:apply-templates select="BlockCounterInfo"/>
               <xsl:apply-templates select="CallCounterInfo"/>
               <xsl:apply-templates select="CacheMissInfo"/>
            </ProfilingReports>
         </CompilationStep>
      </XLTransformationReport><xsl:text>&#10;</xsl:text>
   </xsl:template>

   <xsl:template match="CompileInfo/Compile/Kind" mode="step-name"/>
   <xsl:template match="CompileInfo/Compile/Kind[. = '0']" mode="step-name">compiling</xsl:template>
   <xsl:template match="CompileInfo/Compile/Kind[. = '1']" mode="step-name">compiling</xsl:template>
   <xsl:template match="CompileInfo/Compile/Kind[. = '2']" mode="step-name">compiling</xsl:template>
   <xsl:template match="CompileInfo/Compile/Kind[. = '3']" mode="step-name">linking</xsl:template>

   <xsl:template match="CompileInfo">
      <xsl:apply-templates select="Compile/CompilerName"/>
      <xsl:apply-templates select="Compile/Kind"/>
      <xsl:apply-templates select="Compile/Version"/>
      <xsl:apply-templates select="Compile/Date"/>
      <xsl:if test="count(../StyleSheets/StyleSheet/Locale) = 0">
         <Detail>
            <FieldTitle>Locale</FieldTitle>
            <FieldValue>en_US</FieldValue>
         </Detail>
      </xsl:if>
      <xsl:if test="count(../StyleSheets/StyleSheet/Locale) > 0">
         <xsl:apply-templates select="../StyleSheets/StyleSheet/Locale"/>
      </xsl:if>
      <xsl:apply-templates select="../CommandLines/CommandLine/Name"/>
   </xsl:template>

   <xsl:template match="Compile/CompilerName">
      <Detail>
         <FieldTitle>Compiler name</FieldTitle>
         <FieldValue><xsl:value-of select="text()"/></FieldValue>
      </Detail>
   </xsl:template>

   <xsl:template match="Compile/Kind"/>
   <xsl:template match="Compile/Kind[. = '0']">
      <Detail>
         <FieldTitle>Language</FieldTitle>
         <FieldValue>C</FieldValue>
      </Detail>
   </xsl:template>
   <xsl:template match="Compile/Kind[. = '1']">
      <Detail>
         <FieldTitle>Language</FieldTitle>
         <FieldValue>C++</FieldValue>
      </Detail>
   </xsl:template>
   <xsl:template match="Compile/Kind[. = '2']">
      <Detail>
         <FieldTitle>Language</FieldTitle>
         <FieldValue>Fortran</FieldValue>
      </Detail>
   </xsl:template>
   <xsl:template match="Compile/Kind[. = '3']"/>

   <xsl:template match="Compile/Version">
      <Detail>
         <FieldTitle>Compiler version</FieldTitle>
         <FieldValue><xsl:value-of select="text()"/></FieldValue>
      </Detail>
   </xsl:template>

   <xsl:template match="Compile/Date">
      <Detail>
         <FieldTitle>Report produced on</FieldTitle>
         <FieldValue><xsl:value-of select="text()"/></FieldValue>
      </Detail>
   </xsl:template>

   <xsl:template match="StyleSheets/StyleSheet/Locale">
      <Detail>
         <FieldTitle>Locale</FieldTitle>
         <FieldValue>
         <xsl:choose>
            <xsl:when test=". = 'ja_JP'">ja_JP</xsl:when>
            <xsl:when test=". = 'zh_CN'">zh_CN</xsl:when>
            <xsl:otherwise>en_US</xsl:otherwise>
         </xsl:choose>
         </FieldValue>
      </Detail>
   </xsl:template>

   <xsl:template match="CommandLines/CommandLine/Name">
      <Detail>
         <FieldTitle>Report produced with</FieldTitle>
         <FieldValue><xsl:value-of select="text()"/></FieldValue>
      </Detail>
   </xsl:template>

   <xsl:template match="SourceFiles">
      <xsl:if test="count(SourceFile) > 0">
         <FileList>
            <xsl:apply-templates select="SourceFile"/>
         </FileList>
      </xsl:if>
   </xsl:template>

   <xsl:template match="SourceFile">
      <File>
         <xsl:attribute name="id"><xsl:value-of select="FileId"/></xsl:attribute>
         <xsl:attribute name="name"><xsl:value-of select="FileName"/></xsl:attribute>
         <xsl:apply-templates select="../../SourceRegions"><xsl:with-param name="file-id" select="FileId"/></xsl:apply-templates>
      </File>
   </xsl:template>

   <xsl:template match="SourceRegions"><xsl:param name="file-id"/>
      <xsl:if test="count(SourceRegion[FileId = $file-id]) > 0">
         <RegionList>
            <xsl:apply-templates select="SourceRegion[FileId = $file-id]"/>
         </RegionList>
      </xsl:if>
   </xsl:template>

   <xsl:template match="SourceRegion">
      <Region>
         <xsl:attribute name="id"><xsl:value-of select="RegionId"/></xsl:attribute>
         <xsl:attribute name="name"><xsl:value-of select="RegionName"/></xsl:attribute>
         <xsl:apply-templates select="../../DemangledNames"><xsl:with-param name="region-id" select="RegionId"/></xsl:apply-templates>
         <xsl:if test="StartLineNumber > 0">
            <xsl:attribute name="startLineNumber"><xsl:value-of select="StartLineNumber"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="EndLineNumber > 0">
            <xsl:attribute name="endLineNumber"><xsl:value-of select="EndLineNumber"/></xsl:attribute>
         </xsl:if>
         <xsl:apply-templates select="../../PseudoCodes"><xsl:with-param name="region-id" select="RegionId"/></xsl:apply-templates>
         <xsl:apply-templates select="../../Loops"><xsl:with-param name="region-id" select="RegionId"/></xsl:apply-templates>
      </Region>
   </xsl:template>

   <xsl:template match="DemangledNames"><xsl:param name="region-id"/>
      <xsl:if test="count(DemangledName[RegionId = $region-id]) > 0">
      <xsl:attribute name="demangledName"><xsl:value-of select="DemangledName[RegionId = $region-id]/Name"/></xsl:attribute>
      </xsl:if>
   </xsl:template>

   <xsl:template match="PseudoCodes"><xsl:param name="region-id"/>
      <xsl:if test="count(PseudoCode[RegionId = $region-id]) > 0">
      <Pseudocode>
         <xsl:apply-templates select="PseudoCode[RegionId = $region-id]" mode="write-pseudocode"/>
      </Pseudocode>
      </xsl:if>
   </xsl:template>

   <xsl:template match="PseudoCode" mode="write-pseudocode">
      <xsl:apply-templates select="Body/*" mode="write-pseudocode"/>
   </xsl:template>

   <xsl:template match="Loop" mode="write-pseudocode">
      <PseudoLoop>
         <xsl:attribute name="index"><xsl:value-of select="Id"/></xsl:attribute>
         <xsl:apply-templates select="Body/*" mode="write-pseudocode"/>
      </PseudoLoop>
   </xsl:template>

   <xsl:template match="BasicBlock" mode="write-pseudocode">
      <PseudoBlock>
         <xsl:attribute name="index"><xsl:value-of select="Id"/></xsl:attribute>
         <xsl:apply-templates select="Body/*" mode="write-pseudocode"/>
      </PseudoBlock>
   </xsl:template>

   <xsl:template match="Line" mode="write-pseudocode">
      <PseudoLine>
         <xsl:if test="FileId > '0'">
            <xsl:attribute name="fileId"><xsl:value-of select="FileId"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="Number > '0'">
            <xsl:attribute name="lineNumber"><xsl:value-of select="Number"/></xsl:attribute>
         </xsl:if>
         <xsl:value-of select="Text"/>
      </PseudoLine>
   </xsl:template>

   <xsl:template match="*" mode="write-pseudocode"></xsl:template>

   <xsl:template match="Loops"><xsl:param name="region-id"/>
      <xsl:if test="count(Loop[RegionId = $region-id]) > 0">
      <LoopList>
         <xsl:apply-templates select="Loop[RegionId = $region-id]"/>
      </LoopList>
      </xsl:if>
   </xsl:template>

   <xsl:template match="Loop">
      <Loop>
         <xsl:attribute name="index"><xsl:value-of select="LoopIndex"/></xsl:attribute>
         <xsl:if test="StartLineNumber > 0">
            <xsl:attribute name="startLineNumber"><xsl:value-of select="StartLineNumber"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="EndLineNumber > 0">
            <xsl:attribute name="endLineNumber"><xsl:value-of select="EndLineNumber"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="ParentId > '0'">
            <xsl:attribute name="parentLoopIndex"><xsl:value-of select="ParentId"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="NestingLevel > '0'">
            <xsl:attribute name="nestLevel"><xsl:value-of select="NestingLevel"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="MinCost > '0'">
            <xsl:attribute name="minCost"><xsl:value-of select="MinCost"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="MaxCost > '0'">
            <xsl:attribute name="maxCost"><xsl:value-of select="MaxCost"/></xsl:attribute>
         </xsl:if>
         <xsl:attribute name="iterKind"><xsl:apply-templates select="BitVector" mode="iteration-kind"/></xsl:attribute>
         <xsl:attribute name="iterCount"><xsl:value-of select="IterationCount"/></xsl:attribute>
         <xsl:apply-templates select="BitVector" mode="residual"/>
         <xsl:apply-templates select="BitVector" mode="perfect-nest"/>
         <xsl:apply-templates select="BitVector" mode="well-behaved"/>
         <xsl:apply-templates select="BitVector" mode="may-throw"/>
         <xsl:apply-templates select="BitVector" mode="bump-normalized"/>
         <xsl:apply-templates select="BitVector" mode="guarded"/>
         <xsl:apply-templates select="BitVector" mode="irreducible"/>
         <xsl:apply-templates select="BitVector" mode="lower-bound-normalized"/>
      </Loop>
   </xsl:template>

   <xsl:template match="BitVector[floor(. div '1')  mod '2' = '1']" mode="iteration-kind">exact</xsl:template>
   <xsl:template match="BitVector[floor(. div '2')  mod '2' = '1']" mode="iteration-kind">default</xsl:template>
   <xsl:template match="BitVector[floor(. div '4')  mod '2' = '1']" mode="iteration-kind">PDF</xsl:template>
   <xsl:template match="BitVector[floor(. div '8')  mod '2' = '1']" mode="iteration-kind">array</xsl:template>
   <xsl:template match="BitVector[floor(. div '16') mod '2' = '1']" mode="iteration-kind">user</xsl:template>
   <xsl:template match="BitVector"                                  mode="iteration-kind">estimated</xsl:template>

   <xsl:template match="BitVector[floor(. div '32') mod '2' = '1']" mode="residual"><xsl:attribute name="residual">true</xsl:attribute></xsl:template>
   <xsl:template match="BitVector"                                  mode="residual"><xsl:attribute name="residual">false</xsl:attribute></xsl:template>
   <xsl:template match="BitVector[floor(. div '64') mod '2' = '1']" mode="perfect-nest"><xsl:attribute name="perfectNest">true</xsl:attribute></xsl:template>
   <xsl:template match="BitVector"                                  mode="perfect-nest"><xsl:attribute name="perfectNest">false</xsl:attribute></xsl:template>
   <xsl:template match="BitVector[floor(. div '128') mod '2' = '1']" mode="well-behaved"><xsl:attribute name="wellBehaved">true</xsl:attribute></xsl:template>
   <xsl:template match="BitVector"                                   mode="well-behaved"><xsl:attribute name="wellBehaved">false</xsl:attribute></xsl:template>
   <xsl:template match="BitVector[floor(. div '256') mod '2' = '1']" mode="may-throw"><xsl:attribute name="mayThrow">true</xsl:attribute></xsl:template>
   <xsl:template match="BitVector"                                   mode="may-throw"><xsl:attribute name="mayThrow">false</xsl:attribute></xsl:template>
   <xsl:template match="BitVector[floor(. div '512') mod '2' = '1']" mode="bump-normalized"><xsl:attribute name="bumpNormalized">true</xsl:attribute></xsl:template>
   <xsl:template match="BitVector"                                   mode="bump-normalized"><xsl:attribute name="bumpNormalized">false</xsl:attribute></xsl:template>
   <xsl:template match="BitVector[floor(. div '1024') mod '2' = '1']" mode="guarded"><xsl:attribute name="guarded">true</xsl:attribute></xsl:template>
   <xsl:template match="BitVector"                                    mode="guarded"><xsl:attribute name="guarded">false</xsl:attribute></xsl:template>
   <xsl:template match="BitVector[floor(. div '2048') mod '2' = '1']" mode="irreducible"><xsl:attribute name="irreducible">true</xsl:attribute></xsl:template>
   <xsl:template match="BitVector"                                    mode="irreducible"><xsl:attribute name="irreducible">false</xsl:attribute></xsl:template>
   <xsl:template match="BitVector[floor(. div '4096') mod '2' = '1']" mode="lower-bound-normalized"><xsl:attribute name="lowerBoundNormalized">true</xsl:attribute></xsl:template>
   <xsl:template match="BitVector"                                    mode="lower-bound-normalized"><xsl:attribute name="lowerBoundNormalized">false</xsl:attribute></xsl:template>

   <xsl:template match="Inlines">
      <xsl:if test="count(Inline) > 0">
      <InlineOptimizationList>
         <xsl:apply-templates select="Inline"/>
      </InlineOptimizationList>
      </xsl:if>
   </xsl:template>

   <!-- The following result codes are ignored -->
   <xsl:template match="Inline[ResultCode = '6']"/>	<!-- PragmaNoInlineSpecified -->
   <xsl:template match="Inline[ResultCode = '9']"/>	<!-- CantSeeImplementation -->
   <xsl:template match="Inline[ResultCode = '13']"/>	<!-- CallerHasNoCalls -->
   <xsl:template match="Inline[ResultCode = '21']"/>	<!-- NullProcedure -->
   <xsl:template match="Inline[ResultCode = '22']"/>	<!-- PragmaMcfuncProcedure -->
   <xsl:template match="Inline[ResultCode = '23']"/>	<!-- UnsuitableCallOpcode -->
   <xsl:template match="Inline[ResultCode = '31']"/>	<!-- ZeroPriority -->
   <xsl:template match="Inline[ResultCode = '33']"/>	<!-- HasVarargs -->
   <xsl:template match="Inline[ResultCode = '34']"/>   	<!-- HasFortranIEEEModuleRestrictions -->
   <xsl:template match="Inline[ResultCode = '35']"/>    <!-- AddressTakenVarargsParameter -->
   <xsl:template match="Inline[ResultCode = '38']"/>    <!-- UsesParentCallerData -->
   <xsl:template match="Inline[ResultCode = '40']"/>    <!-- GotoAssignedLabel -->
   <xsl:template match="Inline[ResultCode = '42']"/>	<!-- ConflictingAutoReferenceParameter -->

   <xsl:template match="Inline">
      <InlineOpt>
         <xsl:attribute name="seq"><xsl:value-of select="InlineId"/></xsl:attribute>
         <xsl:attribute name="type"><xsl:apply-templates select="ResultCode"/></xsl:attribute>
         <xsl:attribute name="result"><xsl:apply-templates select="ResultCode" mode="validate-result"/></xsl:attribute>
         <xsl:if test="CallerRegionId > '0'">
            <xsl:attribute name="callerRegionId"><xsl:value-of select="CallerRegionId"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="CalleeRegionId > '0'">
            <xsl:attribute name="calleeRegionId"><xsl:value-of select="CalleeRegionId"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="CallSiteFileId > '0'">
            <xsl:attribute name="callsiteFileId"><xsl:value-of select="CallSiteFileId"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="CallSiteLineNumber > '0'">
            <xsl:attribute name="callsiteLineNumber"><xsl:value-of select="CallSiteLineNumber"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="CallSiteColumnNumber > '0'">
            <xsl:attribute name="callsiteColumnNumber"><xsl:value-of select="CallSiteColumnNumber"/></xsl:attribute>
         </xsl:if>
         <xsl:attribute name="phase"><xsl:apply-templates select="Phase"/></xsl:attribute>
      </InlineOpt>
   </xsl:template>

   <xsl:template match="Phase">unknown</xsl:template>
   <xsl:template match="Phase[. = '0']">Driver</xsl:template>
   <xsl:template match="Phase[. = '1']">C Front End</xsl:template>
   <xsl:template match="Phase[. = '2']">C++ Front End</xsl:template>
   <xsl:template match="Phase[. = '3']">Fortran Front End</xsl:template>
   <xsl:template match="Phase[. = '4']">Low Level Optimizer</xsl:template>
   <xsl:template match="Phase[. = '5']">High Level Optimizer</xsl:template>

   <xsl:template match="ResultCode">unknown</xsl:template>
   <xsl:template match="ResultCode[. = '0']">SuccessfulInline</xsl:template>			<!-- SuccessfulInline -->
   <xsl:template match="ResultCode[. = '1']">FunctionTooBig</xsl:template>			<!-- FunctionTooBig -->
   <xsl:template match="ResultCode[. = '2']">ParameterOfVariablyModifiedType</xsl:template>	<!-- ParameterOfVariablyModifedType -->
   <xsl:template match="ResultCode[. = '3']">RecursiveCall</xsl:template>			<!-- RecusiveCall -->
   <xsl:template match="ResultCode[. = '4']">ArgumentIsVolatile</xsl:template>			<!-- ArgumentIsVolatile -->
   <xsl:template match="ResultCode[. = '5']">MiscellaneousLimitation</xsl:template>		<!-- MiscellaneousLimitation -->
   <xsl:template match="ResultCode[. = '6']">unknown</xsl:template>		                <!-- PragmaNoInlineSpecified -->
   <xsl:template match="ResultCode[. = '7']">VirtualBaseDestructor</xsl:template>		<!-- VirtualBaseDestructor -->
   <xsl:template match="ResultCode[. = '8']">ProhibitedByUser</xsl:template>			<!-- ProhibitedByUser -->
   <xsl:template match="ResultCode[. = '9']">unknown</xsl:template>		                <!-- CantSeeImplementation -->
   <xsl:template match="ResultCode[. = '10']">FunctionTryBlock</xsl:template>			<!-- FunctionTryBlock -->
   <xsl:template match="ResultCode[. = '11']">CallerIsNoopt</xsl:template>			<!-- CallerIsNoopt -->
   <xsl:template match="ResultCode[. = '12']">CallerIsCompact</xsl:template>			<!-- CallerIsCompat -->
   <xsl:template match="ResultCode[. = '13']">unknown</xsl:template>				<!-- CallerHasNoCalls -->
   <xsl:template match="ResultCode[. = '14']">MiscellaneousLimitation</xsl:template> 		<!-- ExceededAliasLimit -->
   <xsl:template match="ResultCode[. = '15']">MiscellaneousLimitation</xsl:template>		<!-- ExceededInliningsLimit -->
   <xsl:template match="ResultCode[. = '16']">MiscellaneousLimitation</xsl:template>		<!-- ExceededCuLimit -->
   <xsl:template match="ResultCode[. = '17']">MiscellaneousLimitation</xsl:template>		<!-- ExceededCallerPdLimit -->
   <xsl:template match="ResultCode[. = '18']">MiscellaneousLimitation</xsl:template>		<!-- ExceededCalleeWithBonusLimit -->
   <xsl:template match="ResultCode[. = '19']">MiscellaneousLimitation</xsl:template>		<!-- ExceededBasicBlockLimit -->
   <xsl:template match="ResultCode[. = '20']">MiscellaneousLimitation</xsl:template>		<!-- ExceededReferenceParameterLimit -->
   <xsl:template match="ResultCode[. = '21']">unknown</xsl:template>				<!-- NullProcedure -->
   <xsl:template match="ResultCode[. = '22']">unknown</xsl:template>				<!-- PragmaMcfuncProcedure -->
   <xsl:template match="ResultCode[. = '23']">unknown</xsl:template>				<!-- UnsuitableCallOpcode -->
   <xsl:template match="ResultCode[. = '24']">CalleeIsNoopt</xsl:template>			<!-- CalleeIsNoopt -->
   <xsl:template match="ResultCode[. = '25']">CalleeIsCompact</xsl:template>			<!-- CalleeIsCompat -->
   <xsl:template match="ResultCode[. = '26']">OptionMismatch</xsl:template>			<!-- MismatchedStrict -->
   <xsl:template match="ResultCode[. = '27']">PrimaryFromSecondaryEntryPoint</xsl:template>	<!-- SecondaryEntryPoint -->
   <xsl:template match="ResultCode[. = '28']">PrimaryFromSecondaryEntryPoint</xsl:template> 	<!-- PrimaryFromSecondaryEntryPoint -->
   <xsl:template match="ResultCode[. = '29']">OptionMismatch</xsl:template> 			<!-- Mismatched64BitInstructions -->
   <xsl:template match="ResultCode[. = '30']">WeakAndNotExplicitlyInline</xsl:template>		<!-- WeakAndNotExplicitlyInline -->
   <xsl:template match="ResultCode[. = '31']">unknown</xsl:template>				<!-- ZeroPriority -->
   <xsl:template match="ResultCode[. = '32']">ExternalLabel</xsl:template>			<!-- HasAddressTakenLabel -->
   <xsl:template match="ResultCode[. = '33']">unknown</xsl:template>				<!-- HasVarargs -->
   <xsl:template match="ResultCode[. = '34']">unknown</xsl:template>				<!-- HasFortranIEEEModuleRestrictions -->
   <xsl:template match="ResultCode[. = '35']">unknown</xsl:template>				<!-- AddressTakenVarargsParameter -->
   <xsl:template match="ResultCode[. = '36']">MismatchedArguments</xsl:template>		<!-- ParameterLengthMismatch -->
   <xsl:template match="ResultCode[. = '37']">MismatchedArguments</xsl:template>		<!-- MismatchedReturnRegisterClass -->
   <xsl:template match="ResultCode[. = '38']">unknown</xsl:template>				<!-- UsesParentCallerData -->
   <xsl:template match="ResultCode[. = '39']">NestedAddressTakenProcedure</xsl:template>	<!-- NestedAddressTakenProcedure -->
   <xsl:template match="ResultCode[. = '40']">unknown</xsl:template>				<!-- GotoAssignedLabel -->
   <xsl:template match="ResultCode[. = '41']">ExternalLabel</xsl:template>			<!-- ExternalLabel -->
   <xsl:template match="ResultCode[. = '42']">unknown</xsl:template> 				<!-- ConflictingAutoReferenceParameter -->
   <xsl:template match="ResultCode[. = '43']">FunctionTooBig</xsl:template>			<!-- LargeStdProc -->
   <xsl:template match="ResultCode[. = '44']">FunctionTooBig</xsl:template>			<!-- NonsimpleFlowStdProc -->
   <xsl:template match="ResultCode[. = '45']">NonIPAObject</xsl:template>			<!-- NonIPAObject -->
   <xsl:template match="ResultCode[. = '46']">OptionMismatch</xsl:template>			<!-- OptionMismatch -->
   <xsl:template match="ResultCode[. = '47']">PDFLowFrequency</xsl:template>			<!-- PDFLowFrequency -->
   <xsl:template match="ResultCode[. = '48']">MismatchedArguments</xsl:template>		<!-- MismatchedArguments -->

   <xsl:template match="ResultCode" mode="validate-result">unknown</xsl:template>
   <xsl:template match="ResultCode[. = '0']" mode="validate-result">success</xsl:template>
   <xsl:template match="ResultCode[. &gt;= '1']" mode="validate-result">fail</xsl:template>

   <xsl:template match="Transforms">
      <xsl:if test="count(Transform) > 0">
      <LoopTransformationList>
         <xsl:apply-templates select="Transform"/>
      </LoopTransformationList>
      </xsl:if>
   </xsl:template>

   <!-- The following transform kinds are ignored -->
   <xsl:template match="Transform[TransformKind = '131594']"/>		<!-- LoopIrreducible -->
   <xsl:template match="Transform[TransformKind = '131596']"/>		<!-- LoopTransformedBeforeDistribution -->

   <xsl:template match="Transform">
      <LoopTransform>
         <xsl:attribute name="seq"><xsl:value-of select="TransformId"/></xsl:attribute>
         <xsl:attribute name="type"><xsl:apply-templates select="TransformKind"/></xsl:attribute>
         <xsl:attribute name="result"><xsl:apply-templates select="TransformKind" mode="validate-result"/></xsl:attribute>
         <xsl:if test="RegionId > '0'">
            <xsl:attribute name="regionId"><xsl:value-of select="RegionId"/></xsl:attribute>
         </xsl:if>
         <xsl:apply-templates select="../../TransformAttributes" mode="loop-index"><xsl:with-param name="transform-id" select="TransformId"/></xsl:apply-templates>
         <xsl:if test="LineNumber > '0'">
            <xsl:attribute name="lineNumber"><xsl:value-of select="LineNumber"/></xsl:attribute>
         </xsl:if>
         <xsl:attribute name="phase"><xsl:apply-templates select="Phase"/></xsl:attribute>
         <xsl:apply-templates select="../../TransformAttributes" mode="attr-list"><xsl:with-param name="transform-id" select="TransformId"/><xsl:with-param name="transform-kind" select="TransformKind"/></xsl:apply-templates>
      </LoopTransform>
   </xsl:template>

   <xsl:template match="TransformKind">unknown</xsl:template>
   <xsl:template match="TransformKind[. = '131577']">NonNormalizableLoop</xsl:template> 		<!-- NonNormalizableLoop -->
   <xsl:template match="TransformKind[. = '131578']">CompleteLoopUnroll</xsl:template>			<!-- CompleteLoopUnroll -->
   <xsl:template match="TransformKind[. = '131579']">OuterLoopUnroll</xsl:template>			<!-- OuterLoopUnroll -->
   <xsl:template match="TransformKind[. = '131580']">InnerLoopUnroll</xsl:template>			<!-- InnerLoopUnroll -->
   <xsl:template match="TransformKind[. = '131581']">LoopFusion</xsl:template>				<!-- LoopFusion -->
   <xsl:template match="TransformKind[. = '131582']">LoopDistribution</xsl:template>			<!-- LoopDistribution -->
   <xsl:template match="TransformKind[. = '131583']">LoopParallelized</xsl:template>			<!-- LoopParallelized -->
   <xsl:template match="TransformKind[. = '131584']">LoopCarriedDependence</xsl:template>		<!-- LoopCarriedDependence -->
   <xsl:template match="TransformKind[. = '131585']">LoopHasVolatileVariable</xsl:template>		<!-- LoopHasVolatileVariable -->
   <xsl:template match="TransformKind[. = '131586']">LoopHasSideEffectsCall</xsl:template>		<!-- LoopHasSideEffectsCall -->
   <xsl:template match="TransformKind[. = '131587']">LoopInterchange</xsl:template>			<!-- LoopInterchange -->
   <xsl:template match="TransformKind[. = '131588']">LoopReversal</xsl:template>			<!-- LoopReversal -->
   <xsl:template match="TransformKind[. = '131589']">LoopSkew</xsl:template>				<!-- LoopSkew -->
   <xsl:template match="TransformKind[. = '131590']">LoopHasPrivateVariables</xsl:template>		<!-- LoopHasPrivateVariables -->
   <xsl:template match="TransformKind[. = '131592']">LoopVector</xsl:template>				<!-- LoopVector -->
   <xsl:template match="TransformKind[. = '131594']">unknown</xsl:template>				<!-- LoopIrreducible -->
   <xsl:template match="TransformKind[. = '131595']">LoopNotCountable</xsl:template>			<!-- LoopNotCountable -->
   <xsl:template match="TransformKind[. = '131596']">unknown</xsl:template>				<!-- LoopTransformedBeforeDistribution -->
   <xsl:template match="TransformKind[. = '131597']">LoopNotPerfectNest</xsl:template>			<!-- LoopNotPerfectNest -->
   <xsl:template match="TransformKind[. = '131598']">LoopHasSideEffects</xsl:template>			<!-- LoopHasSideEffects -->
   <xsl:template match="TransformKind[. = '131599']">LoopHasUserReduction</xsl:template>		<!-- LoopHasUserReduction -->
   <xsl:template match="TransformKind[. = '131600']">LoopHasDependencies</xsl:template>			<!-- LoopHasDependencies -->
   <xsl:template match="TransformKind[. = '131601']">LoopHasNoDataDependence</xsl:template>		<!-- LoopHasNoDataDependence -->
   <xsl:template match="TransformKind[. = '131602']">UnrollLimitExceeded</xsl:template>			<!-- UnrollLimitExceeded -->
   <xsl:template match="TransformKind[. = '131603']">LoopBlocked</xsl:template>				<!-- LoopBlocked -->
   <xsl:template match="TransformKind[. = '131616']">LoopVectorVersion</xsl:template>			<!-- LoopVectorVersion -->
   <xsl:template match="TransformKind[. = '131617']">LoopBlockGather</xsl:template>			<!-- LoopBlockGather -->
   <xsl:template match="TransformKind[. = '131618']">LoopNestGather</xsl:template>			<!-- LoopNestGather -->
   <xsl:template match="TransformKind[. = '131624']">ContainsNonVectorizableReduction</xsl:template>	<!-- ContainsNonVectorizableReduction -->
   <xsl:template match="TransformKind[. = '131625']">IterationCountTooSmall</xsl:template>		<!-- IterationCountTooSmall -->
   <xsl:template match="TransformKind[. = '131626']">NonInnermostLoop</xsl:template>			<!-- NonInnermostLoop -->
   <xsl:template match="TransformKind[. = '131627']">AliasingInducedDependence</xsl:template>		<!-- AliasingInducedDependence -->
   <xsl:template match="TransformKind[. = '131628']">NonVectorizableAlignment</xsl:template>		<!-- NonVectorizableAlignment -->
   <xsl:template match="TransformKind[. = '131629']">UnsupportedOperation</xsl:template>		<!-- UnsupportedOperation -->
   <xsl:template match="TransformKind[. = '131630']">UnsupportedStructure</xsl:template>		<!-- UnsupportedStructure -->
   <xsl:template match="TransformKind[. = '131631']">ContainsFunctionCall</xsl:template>		<!-- ContainsFunctionCall -->
   <xsl:template match="TransformKind[. = '131632']">NonVectorizableStride</xsl:template>		<!-- NonVectorizableStride -->
   <xsl:template match="TransformKind[. = '131633']">LoopNotSimdize</xsl:template>			<!-- LoopNotSimdize -->
   <xsl:template match="TransformKind[. = '131634']">LoopSimdize</xsl:template>				<!-- LoopSimdize -->
   <xsl:template match="TransformKind[. = '131635']">LoopSimdize</xsl:template>				<!-- LoopSimdize -->
   <xsl:template match="TransformKind[. = '131636']">DataDependence</xsl:template>			<!-- DataDependence -->
   <xsl:template match="TransformKind[. = '131637']">NotProfitable</xsl:template>			<!-- NotProfitable -->
   <xsl:template match="TransformKind[. = '131638']">UnsupportedVectorTypes</xsl:template>		<!-- UnsupportedVectorTypes -->
   <xsl:template match="TransformKind[. = '131639']">ContainsControlFlow</xsl:template>			<!-- ContainsControlFlow -->
   <xsl:template match="TransformKind[. = '131640']">UserSpecifiedNoSIMD</xsl:template>			<!-- UserSpecifiedNoSIMD -->
   <xsl:template match="TransformKind[. = '131641']">ProhibitedByOption</xsl:template>			<!-- ProhibitedByOption -->
   <xsl:template match="TransformKind[. = '131642']">ContainsVolatileReference</xsl:template>		<!-- ContainsVolatileReference -->
   <xsl:template match="TransformKind[. = '131643']">NonStrideOneStore</xsl:template>			<!-- NonStrideOneStore -->
   <xsl:template match="TransformKind[. = '131644']">NonStrideOneInShift</xsl:template>			<!-- NonStrideOneInShift -->
   <xsl:template match="TransformKind[. = '131645']">StrideOneRequireBF1</xsl:template>			<!-- StrideOneRequireBF1 -->

   <xsl:template match="TransformKind[. = '131666']">LoopRolled</xsl:template>
   <xsl:template match="TransformKind[. = '131667']">LoopCollapsed</xsl:template>

   <xsl:template match="TransformKind[. = '131690']">DataPrefetch</xsl:template>			<!-- DataPrefetch -->
   <xsl:template match="TransformKind[. = '131691']">AssistThreadDataPrefetch</xsl:template>		<!-- AssistThreadDataPrefetch -->
   
   <xsl:template match="TransformKind[. = '131723']">UPCForallLoopVersioned</xsl:template>
   <xsl:template match="TransformKind[. = '131724']">UPCForallOpt</xsl:template>
   <xsl:template match="TransformKind[. = '131726']">UPCRemoteUpdate</xsl:template>
   <xsl:template match="TransformKind[. = '131727']">UPCArrayIdiom</xsl:template>
   <xsl:template match="TransformKind[. = '131728']">UPCPrivatizedRef1</xsl:template>
   <xsl:template match="TransformKind[. = '131729']">UPCPrivatizedRef2</xsl:template>
   <xsl:template match="TransformKind[. = '131730']">UPCCoalesing</xsl:template>
   <xsl:template match="TransformKind[. = '131733']">UPCForallVersioningPtrNotInvariant</xsl:template>
   <xsl:template match="TransformKind[. = '131736']">UPCForallIVUsedInMultipleDims</xsl:template>
   <xsl:template match="TransformKind[. = '131737']">UPCForallNotInnerParallel</xsl:template>
   <xsl:template match="TransformKind[. = '131738']">UPCRemoteUpdateUnknownPattern</xsl:template>
   <xsl:template match="TransformKind[. = '131739']">UPCArrayIdiomDiffBlkFactors</xsl:template>
   <xsl:template match="TransformKind[. = '131740']">UPCArrayIdiomBlkFactorOne</xsl:template>   
   
   <xsl:template match="TransformKind[. = '458825']">LoopUnroll</xsl:template>		                <!-- LoopUnroll -->
   <xsl:template match="TransformKind[. = '458826']">FullLoopUnroll</xsl:template>		        <!-- FullLoopUnroll -->
   <xsl:template match="TransformKind[. = '458827']">ModuloSchedule</xsl:template>		        <!-- ModuloSchedule -->

   <xsl:template match="TransformKind[. = '458830']">LoopHasSpills</xsl:template>
   <xsl:template match="TransformKind[. = '458831']">LoopHasCycles</xsl:template>
   <xsl:template match="TransformKind[. = '458832']">InstructionThresholdExceeded</xsl:template>
   <xsl:template match="TransformKind[. = '458833']">BasicBlockThresholdExceeded</xsl:template>
   <xsl:template match="TransformKind[. = '458834']">ControlFlowTooComplicated</xsl:template>
   <xsl:template match="TransformKind[. = '458835']">RegisterPressureTooHigh</xsl:template>
   <xsl:template match="TransformKind[. = '458836']">NoValidSchedule</xsl:template>


   <xsl:template match="TransformKind" mode="validate-result">unknown</xsl:template>
   <xsl:template match="TransformKind[. = '131577']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131578']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131579']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131580']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131581']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131582']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131583']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131584']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131585']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131586']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131587']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131588']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131589']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131590']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131592']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131594']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131595']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131596']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131597']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131598']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131599']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131600']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131601']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131602']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131603']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131616']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131617']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131618']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131624']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131625']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131626']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131627']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131628']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131629']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131630']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131631']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131632']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131633']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131634']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131635']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131636']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131637']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131638']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131639']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131640']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131641']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131642']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131643']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131644']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131645']" mode="validate-result">fail</xsl:template>

   <xsl:template match="TransformKind[. = '131666']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131667']" mode="validate-result">success</xsl:template>

   <xsl:template match="TransformKind[. = '131690']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131691']" mode="validate-result">success</xsl:template>

   <xsl:template match="TransformKind[. = '131723']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131724']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131726']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131727']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131728']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131729']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131730']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '131733']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131736']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131737']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131738']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131739']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '131740']" mode="validate-result">fail</xsl:template>
   
   <xsl:template match="TransformKind[. = '458825']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '458826']" mode="validate-result">success</xsl:template>
   <xsl:template match="TransformKind[. = '458827']" mode="validate-result">success</xsl:template>

   <xsl:template match="TransformKind[. = '458830']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '458831']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '458832']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '458833']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '458834']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '458835']" mode="validate-result">fail</xsl:template>
   <xsl:template match="TransformKind[. = '458836']" mode="validate-result">fail</xsl:template>

   <!-- Attributes handling: START -->

   <xsl:template match="TransformAttributes" mode="loop-index"><xsl:param name="transform-id"/>
      <xsl:apply-templates select="TransformAttribute[TransformId = $transform-id and Index = '1']" mode="loop-index"/>
   </xsl:template>

   <xsl:template match="TransformAttribute" mode="loop-index">
      <xsl:if test="AttributeText > 0">
         <xsl:attribute name="loopIndex"><xsl:value-of select="AttributeText"/></xsl:attribute>
      </xsl:if>
   </xsl:template>

   <xsl:template match="TransformAttributes" mode="attr-list"><xsl:param name="transform-id"/><xsl:param name="transform-kind"/>
      <xsl:if test="$transform-kind='131579' or
                           $transform-kind='131580' or
                           $transform-kind='131581' or
                           $transform-kind='131582' or
                           $transform-kind='131584' or
                           $transform-kind='131585' or
                           $transform-kind='131586' or
                           $transform-kind='131590' or
                           $transform-kind='131628' or
                           $transform-kind='131629' or
                           $transform-kind='131632' or
                           $transform-kind='131636' or
                           $transform-kind='131641' or
                           $transform-kind='131642' or
                           $transform-kind='131643' or
                           $transform-kind='131644' or
                           $transform-kind='131645' or
                           $transform-kind='458825' or
                           $transform-kind='458826' or
                           $transform-kind='458827' or
                           $transform-kind='458830' or
                           $transform-kind='458831' or
                           $transform-kind='458832' or
                           $transform-kind='458833' or
                           
                           $transform-kind='131726' or
                           $transform-kind='131730' or
                           $transform-kind='131733' or
                           $transform-kind='131738' or
                           $transform-kind='131740' or
                           $transform-kind='131727' or
                           $transform-kind='131728' or
                           $transform-kind='131729' or
                           $transform-kind='131739'">
      <xsl:apply-templates select="." mode="attr-list2"><xsl:with-param name="transform-id" select="$transform-id"/><xsl:with-param name="transform-kind" select="$transform-kind"/></xsl:apply-templates>
      </xsl:if>
   </xsl:template>

   <xsl:template match="TransformAttributes" mode="attr-list2"><xsl:param name="transform-id"/><xsl:param name="transform-kind"/>
      <xsl:if test="count(TransformAttribute[TransformId = $transform-id and Index != '1']) > 0">
      <AttributeList>
         <xsl:apply-templates select="TransformAttribute[TransformId = $transform-id and Index != '1']" mode="attr-element"><xsl:with-param name="transform-kind" select="$transform-kind"/></xsl:apply-templates>
      </AttributeList>
      </xsl:if>
   </xsl:template>

   <xsl:template match="TransformAttribute" mode="attr-element"><xsl:param name="transform-kind"/>
      <Attribute>
         <AttributeTitle><xsl:apply-templates select="." mode="attr-title"><xsl:with-param name="transform-kind" select="$transform-kind"/></xsl:apply-templates></AttributeTitle>
         <AttributeValue><xsl:value-of select="AttributeText"/></AttributeValue>
      </Attribute>
   </xsl:template>

   <xsl:template match="TransformAttribute" mode="attr-title"><xsl:param name="transform-kind"/>unknown</xsl:template>
   <xsl:template match="TransformAttribute[Index = '2']" mode="attr-title"><xsl:param name="transform-kind"/>
      <xsl:choose>
         <xsl:when test="$transform-kind='131579'">Unroll Factor</xsl:when>
         <xsl:when test="$transform-kind='131580'">Unroll Factor</xsl:when>
         <xsl:when test="$transform-kind='131581'">Loop Line Number</xsl:when>
         <xsl:when test="$transform-kind='131582'">Loop Line Number (Child)</xsl:when>
         <xsl:when test="$transform-kind='131584'">Variable Name</xsl:when>
         <xsl:when test="$transform-kind='131585'">Variable Name</xsl:when>
         <xsl:when test="$transform-kind='131586'">Function Name</xsl:when>
         <xsl:when test="$transform-kind='131590'">Variable Name</xsl:when>
         <xsl:when test="$transform-kind='131628'">Memory Reference</xsl:when>
         <xsl:when test="$transform-kind='131629'">Operation Name</xsl:when>
         <xsl:when test="$transform-kind='131632'">Memory Reference</xsl:when>
         <xsl:when test="$transform-kind='131636'">Memory Reference</xsl:when>
         <xsl:when test="$transform-kind='131641'">Option Name</xsl:when>
         <xsl:when test="$transform-kind='131642'">Memory Reference</xsl:when>
         <xsl:when test="$transform-kind='131643'">Memory Reference</xsl:when>
         <xsl:when test="$transform-kind='131644'">Memory Reference</xsl:when>
         <xsl:when test="$transform-kind='131645'">Memory Reference</xsl:when>
         <xsl:when test="$transform-kind='131726'">Shared Reference</xsl:when>
         <xsl:when test="$transform-kind='131727'">Shared Access</xsl:when>
         <xsl:when test="$transform-kind='131728'">Privatized Reference</xsl:when>
         <xsl:when test="$transform-kind='131729'">Privatized Reference</xsl:when>
         <xsl:when test="$transform-kind='131730'">Shared Reference</xsl:when>
         <xsl:when test="$transform-kind='131733'">Pointer-to-Shared</xsl:when>
         <xsl:when test="$transform-kind='131738'">Shared Reference</xsl:when>
         <xsl:when test="$transform-kind='131739'">Shared Symbol</xsl:when>
         <xsl:when test="$transform-kind='131740'">Shared Symbol</xsl:when>
         <xsl:when test="$transform-kind='458825'">Unroll Factor</xsl:when>
         <xsl:when test="$transform-kind='458826'">Unroll Factor</xsl:when>
         <xsl:when test="$transform-kind='458827'">Initiation Interval</xsl:when>
         <xsl:when test="$transform-kind='458830'">Spills Quantity</xsl:when>
         <xsl:when test="$transform-kind='458831'">Cycles Quantity</xsl:when>
         <xsl:when test="$transform-kind='458832'">Instructions Quantity</xsl:when>
         <xsl:when test="$transform-kind='458833'">Basic Blocks Quantity</xsl:when>
         <xsl:otherwise>unknown</xsl:otherwise>
      </xsl:choose>
   </xsl:template>
   <xsl:template match="TransformAttribute[Index = '3']" mode="attr-title"><xsl:param name="transform-kind"/>
      <xsl:choose>
         <xsl:when test="$transform-kind='131581'">Loop Line Number</xsl:when>
         <xsl:when test="$transform-kind='131582'">Loop Line Number (Parent)</xsl:when>
         <xsl:when test="$transform-kind='131727'">Function Name</xsl:when>
         <xsl:when test="$transform-kind='131728'">Line Number</xsl:when>
         <xsl:when test="$transform-kind='131739'">Shared symbol</xsl:when>
         <xsl:when test="$transform-kind='458832'">Threshold</xsl:when>
         <xsl:when test="$transform-kind='458833'">Threshold</xsl:when>
         <xsl:otherwise>unknown</xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!-- Attributes handling: END -->

   <xsl:template match="DataReorganizations">
      <xsl:if test="count(DataReorganization) > 0">
      <DataReorganizationList>
         <xsl:apply-templates select="DataReorganization"/>
      </DataReorganizationList>
      </xsl:if>
   </xsl:template>

   <xsl:template match="DataReorganization">
      <DataReorg>
         <xsl:attribute name="seq"><xsl:value-of select="DataId"/></xsl:attribute>
         <xsl:attribute name="type"><xsl:apply-templates select="DataKind"/></xsl:attribute>
         <xsl:attribute name="dataName"><xsl:value-of select="DataName"/></xsl:attribute>
         <xsl:if test="Category != ''">
            <xsl:attribute name="category"><xsl:value-of select="Category"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="RegionId > 0">
            <xsl:attribute name="regionId"><xsl:value-of select="RegionId"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="LineId > 0">
            <xsl:attribute name="lineNumber"><xsl:value-of select="LineId"/></xsl:attribute>
         </xsl:if>
         <xsl:attribute name="phase"><xsl:apply-templates select="Phase"/></xsl:attribute>
      </DataReorg>
   </xsl:template>

   <xsl:template match="DataKind">unknown</xsl:template>
   <xsl:template match="DataKind[. = '0']">ArraySplitting</xsl:template>
   <xsl:template match="DataKind[. = '1']">ArrayTransposing</xsl:template>
   <xsl:template match="DataKind[. = '2']">MemoryAllocationMerging</xsl:template>
   <xsl:template match="DataKind[. = '3']">ArrayInterleaving</xsl:template>
   <xsl:template match="DataKind[. = '4']">CommonBlockSplitting</xsl:template>
   <xsl:template match="DataKind[. = '5']">ArrayCoalescing</xsl:template>

   <xsl:template match="BlockCounterInfo">
      <xsl:if test="count(BlockCounterRow) > 0">
      <BlockCounterList>
         <xsl:apply-templates select="BlockCounterRow"/>
      </BlockCounterList>
      </xsl:if>
   </xsl:template>

   <xsl:template match="BlockCounterRow">
      <BlockCounter>
         <xsl:attribute name="regionId"><xsl:value-of select="RegionId"/></xsl:attribute>
         <xsl:attribute name="execCount"><xsl:value-of select="InvokeNumber"/></xsl:attribute>
         <xsl:if test="CoveredBlock != ''">
            <xsl:attribute name="coveredBlock"><xsl:value-of select="CoveredBlock"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="TotalBlock != ''">
            <xsl:attribute name="totalBlock"><xsl:value-of select="TotalBlock"/></xsl:attribute>
         </xsl:if>
         <xsl:apply-templates select="../../BlockCounters"><xsl:with-param name="region-id" select="RegionId"/></xsl:apply-templates>
      </BlockCounter>
   </xsl:template>

   <xsl:template match="BlockCounters"><xsl:param name="region-id"/>
      <xsl:if test="count(BlockCounter[RegionId = $region-id]) > 0">
      <BlockList>
         <xsl:apply-templates select="BlockCounter[RegionId = $region-id]"/>
      </BlockList>
      </xsl:if>
   </xsl:template>

   <xsl:template match="BlockCounter">
      <Block>
         <xsl:attribute name="index"><xsl:value-of select="BlockIndex"/></xsl:attribute>
         <xsl:attribute name="execCount"><xsl:value-of select="ExecutionCount"/></xsl:attribute>
         <xsl:if test="StartLineNumber > 0">
            <xsl:attribute name="startLineNumber"><xsl:value-of select="StartLineNumber"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="EndLineNumber > 0">
            <xsl:attribute name="endLineNumber"><xsl:value-of select="EndLineNumber"/></xsl:attribute>
         </xsl:if>
      </Block>
   </xsl:template>

   <xsl:template match="CallCounterInfo">
      <xsl:if test="count(CallCounterRow) > 0">
      <CallCounterList>
         <xsl:apply-templates select="CallCounterRow"/>
      </CallCounterList>
      </xsl:if>
   </xsl:template>

   <xsl:template match="CallCounterRow">
      <CallCounter>
         <xsl:attribute name="regionId"><xsl:value-of select="RegionId"/></xsl:attribute>
         <xsl:attribute name="execCount"><xsl:value-of select="InvokeNumber"/></xsl:attribute>
         <xsl:if test="CoveredCall != ''">
            <xsl:attribute name="coveredCall"><xsl:value-of select="CoveredCall"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="TotalCall != ''">
            <xsl:attribute name="totalCall"><xsl:value-of select="TotalCall"/></xsl:attribute>
         </xsl:if>
         <xsl:apply-templates select="../../CallCounters"><xsl:with-param name="region-id" select="RegionId"/></xsl:apply-templates>
      </CallCounter>
   </xsl:template>

   <xsl:template match="CallCounters"><xsl:param name="region-id"/>
      <xsl:if test="count(CallCounter[RegionId = $region-id]) > 0">
      <CallList>
         <xsl:apply-templates select="CallCounter[RegionId = $region-id]"/>
      </CallList>
      </xsl:if>
   </xsl:template>

   <xsl:template match="CallCounter">
      <Call>
         <xsl:attribute name="name"><xsl:value-of select="CallRegionName"/></xsl:attribute>
         <xsl:attribute name="execCount"><xsl:value-of select="ExecutionCount"/></xsl:attribute>
         <xsl:if test="LineNumber > 0">
            <xsl:attribute name="lineNumber"><xsl:value-of select="LineNumber"/></xsl:attribute>
         </xsl:if>
      </Call>
   </xsl:template>

   <xsl:template match="CacheMissInfo">
      <xsl:if test="count(CacheMiss) > 0">
      <CacheMissList>
         <xsl:apply-templates select="CacheMiss"/>
      </CacheMissList>
      </xsl:if>
   </xsl:template>

   <xsl:template match="CacheMiss">
      <CacheMiss>
         <xsl:attribute name="memoryReference"><xsl:value-of select="MemoryReference"/></xsl:attribute>
         <xsl:if test="RegionId > 0">
            <xsl:attribute name="regionId"><xsl:value-of select="RegionId"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="LineNumber > 0">
            <xsl:attribute name="lineNumber"><xsl:value-of select="LineNumber"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="CacheLevel != ''">
            <xsl:attribute name="cacheLevel"><xsl:value-of select="CacheLevel"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="CacheMissCount != ''">
            <xsl:attribute name="cacheMissCount"><xsl:value-of select="CacheMissCount"/></xsl:attribute>
         </xsl:if>
         <xsl:if test="CacheMissRate != ''">
            <xsl:attribute name="cacheMissRate"><xsl:value-of select="CacheMissRate"/></xsl:attribute>
         </xsl:if>
      </CacheMiss>
   </xsl:template>

</xsl:stylesheet>
